@@ -37,6 +37,8 @@ use constant MODE_PARSED    => 300;
 	# Artwork profiles:
 	my $profiles = { 'nano_3g' => [ { height=>320, width=>320, storage_id=>1060, bpp=>16,  },  { height=>128, width=>128, storage_id=>1055, bpp=>16, },
 	                                { height=>56,  width=>56,  storage_id=>1061, bpp=>16, drop=>112}                                                     ],
+	                 'classic' => [ { height=>320, width=>320, storage_id=>1060, bpp=>16,  },  { height=>128, width=>128, storage_id=>1055, bpp=>16, },
+	                                { height=>56,  width=>56,  storage_id=>1061, bpp=>16, drop=>112}                                                     ],
 	                 'nano'    => [ { height=>100, width=>100, storage_id=>1027, bpp=>16,  },  { height=> 42, width=> 42, storage_id=>1031, bpp=>16, },  ],
 	                 'video'   => [ { height=>200, width=>200, storage_id=>1029, bpp=>16,  },  { height=>100, width=>100, storage_id=>1028, bpp=>16,  }, ],
 	               };
@@ -70,6 +72,8 @@ use constant MODE_PARSED    => 300;
 			return $self;
 		}
 		
+		binmode(AWDB);
+		
 		my $obj = { offset => 0, childs => 1, fd=>*AWDB, awdb => 1,
 		               callback => {
 		                              PACKAGE=>$self, mhod => { item  => '_MhodItem'  },
@@ -168,6 +172,7 @@ use constant MODE_PARSED    => 300;
 		foreach my $mr (@$mode) {
 			my $buff = '';
 			open(IM, "-|") || exec("convert", "-resize", "$mr->{height}x$mr->{width}!", "-depth", 8, $file, "RGB:-");
+			binmode(IM);
 			while(<IM>) { $buff .= $_  }
 			close(IM);
 			
@@ -222,6 +227,7 @@ use constant MODE_PARSED    => 300;
 		if(! open(ITHMB, "+<", $fpath) ) {
 			open(ITHMB, ">", $fpath) or die "Unable to write to $fpath : $!\n";
 		}
+		binmode(ITHMB);
 		seek(ITHMB,$start,0) or die "Unable to seek to $start at $fnam\n";
 		print ITHMB $args{Data};
 		$end   = tell(ITHMB);
@@ -248,6 +254,7 @@ use constant MODE_PARSED    => 300;
 		my $bak = $self->{artworkdb}.".old";
 		
 		open(AD, "+>", $tmp) or die "Unable to write $self->{artworkdb} : $!\n";
+		binmode(AD);
 		my $fd = *AD;
 		
 		my $mhfd_fixup = tell($fd);
@@ -504,6 +511,7 @@ package GNUpod::ArtworkDB::RGB;
 		my($self,%args) = @_;
 		my $buff = '';
 		open(F, "<", $args{File}) or return undef;
+		binmode(F);
 		while(<F>) { $buff .= $_; }
 		close(F);
 		$self->SetData(Data=>$buff, Width=>$args{Width}, Height=>$args{Height});
@@ -537,7 +545,6 @@ package GNUpod::ArtworkDB::RGB;
 		return $out;
 	}
 
-=head
 	sub RGB565ToBitmap {
 		my($self) = @_;
 		my $size = length($self->{data});
@@ -556,8 +563,6 @@ package GNUpod::ArtworkDB::RGB;
 		$out .= pack("H*", "0000010018000000");
 		$out .= pack("H*", "0000c0d40100130b0000130b00000000000000000000");
 		
-		print "Data is $size bytes and has $pixl pixels: bpp : $bpp\n";
-		
 		for(my $h = $self->{dimH}; $h > 0; $h--) {
 			my $line = '';
 			for(my $w = 0; $w < $self->{dimW}; $w++) {
@@ -572,6 +577,5 @@ package GNUpod::ArtworkDB::RGB;
 		}
 		return $out;
 	}
-=cut
 	
 1;
